﻿/**CFile***********************************************************************

  FileName    [main.c]

  Synopsis [File to open and close the file given as first parameter.]

  Description [The program opens a file, reads its data and stores it into
  different data structures.]

  Author      [Abelardo Pardo <abelardo.pardo@uc3m.es>]

  Copyright   [Copyright (c) 2009 Carlos III University of Madrid
  All rights reserved.

  Permission is hereby granted, without written agreement and without license
  or royalty fees, to use, copy, modify, and distribute this software and its
  documentation for any purpose, provided that the above copyright notice and
  the following two paragraphs appear in all copies of this software.

  IN NO EVENT SHALL THE CARLOS III UNIVERSITY OF MADRID BE LIABLE TO ANY PARTY 
  FOR DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES ARISING 
  OUT OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION, EVEN IF THE CARLOS III
  UNIVERSITY OF MADRID HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

  THE CARLOS III UNIVERSITY OF MADRID SPECIFICALLY DISCLAIMS ANY WARRANTIES,
  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
  FITNESS FOR A PARTICULAR PURPOSE.  THE SOFTWARE PROVIDED HEREUNDER IS ON AN
  "AS IS" BASIS, AND CARLOS III UNIVERSITY OF MADRID HAS NO OBLIGATION TO 
  PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS.]

******************************************************************************/

#include <stdio.h> 
#include <errno.h>

/*---------------------------------------------------------------------------*/
/* Definition of functions                                                   */
/*---------------------------------------------------------------------------*/
int main(int arg_count, char *arg_strings[]) 
{
    FILE *data_input;

    /* Check if there is a filename as argument */
    if (arg_count < 2) 
    {
      printf("ERROR: Incorrect number of arguments. Filename required.\n");
      return 1;
    }

    /* Open the file and check for errors */
    data_input = fopen(arg_strings[1], "r");
    if (data_input == NULL) 
    {
      int error = errno;
      printf("ERROR: Unable to open file %s\n", arg_strings[1]);
      if (error == EINVAL) 
      {
        printf("Incorrect mode given to fopen\n");
      }
      return 1;
    }

    /* Close the file and check for errors */
    if (fclose(data_input) != 0) 
    {
      int error = errno;
      printf("ERROR: Unable to close file %s\n", arg_strings[1]);
      if (error == EBADF) 
      {
        printf("Incorrect file descriptor given\n");
      }
      return 1;
    }
    return 0;
}

